#!/bin/sh

initialized=$(uci -q get ati.@ati[0].initialized)
board=$(cat /var/sysinfo/model)
mac_id=$(sh /www/ati/scripts/get-id.sh)
ati_id=$( printf "ATI-Straton-%d" $mac_id )

initializeOnion () {
	logger "Initialize Onion Board..."
	uci set system.@system[0].klogconloglevel=5
	sh /www/ati/scripts/onion.reset-network.sh
	sh /www/ati/scripts/onion.set-hostname.sh "$ati_id"
	uci commit
}

initializeLinkit () {
	logger "Initialize Linkit Board..."
	sh /www/ati/scripts/linkit.reset-network.sh
	sh /www/ati/scripts/linkit.set-hostname.sh "$ati_id"
	uci commit
}

initializeDefaults () {
	logger "Initialize Defaults..."
	uci set ati.@ati[0].id=""$mac_id""
	uci set ati.@ati[0].initialized='1'
	uci set ati.@ati[0].show_wizard='1'
	uci set ati.@ati[0].spots_count='0'
}

if [ "1" != "$initialized" ] || [ "$1" == "-f" ] || [ "$1" == "--force" ]; then
	logger "Initialize ATI Device..."

	sleep 2
	mac_id=$(sh /www/ati/scripts/get-id.sh)
	ati_id=$( printf "ATI-Straton-%d" $mac_id )

	logger "Use ID $mac_id ..."
	
	initializeDefaults

	if [ "$board" == "Onion Omega2+" ] || [ "$board" == "Onion Omega2 Pro" ]; then
		initializeOnion 
	else
		initializeLinkit
	fi

else
	logger "ATI Device already initialized..."
fi

logger "ATI Device initialized:"
logger "Board: $board"
logger "Hostname:" $(uci get system.@system[0].hostname)
logger "ID:" $(uci get ati.@ati[0].id)