#!/bin/sh

# $1 ... MODE (AP, STA)
# $2 ... SSID
# $3 ... PASSWORD
# $4 ... ENCRYPTION

mode=$1
ssid=$2
password=$3
encryption=$4

uci_configure_AP() {
	echo "Configure Wifi AccessPoint... ("$ssid", "$encryption")"
	uci -q batch <<EOF
set wireless.ap.encryption='$encryption'
set wireless.ap.key='$password'
set wireless.ap.ssid='$ssid'
set wireless.sta.disabled='1'
set wireless.sta.encryption='none'
set wireless.sta.key=''
set wireless.sta.ssid=''
set network.lan.ipaddr='192.168.100.1'
EOF

	uci commit
	#wifi
}

uci_configure_STA() {
	echo "Configure Wifi Station..."
	hostname=$(uci get system.@system[0].hostname)

	uci -q batch <<EOF
set wireless.sta.encryption='$encryption'
set wireless.sta.key='$password'
set wireless.sta.ssid='$ssid'
set wireless.sta.disabled='0'
set network.lan.ipaddr='192.168.101.1'
EOF

	uci commit
	#wifi
#	ifconfig ra0 down
}

uci_wifi_OFF() {
	echo "Turn off Wifi..."
	uci -q batch <<EOF
set wireless.sta.disabled='1'
set wireless.ap.disabled='1'
EOF
	uci commit
	wifi
}

uci_wifi_ON() {
	echo "Turn on Wifi..."
	ssid=$(uci -q get wireless.sta.ssid)
	if [ "$ssid" != '' ]; then
		password=$(uci get wireless.sta.key)
		encryption=$(uci get wireless.sta.encryption)
		uci_configure_STA
	else
		ssid=$(uci get wireless.ap.ssid)
		password=$(uci get wireless.ap.key)
		encryption=$(uci get wireless.ap.encryption)
		uci_configure_AP
	fi
}

uci_ethernet_host() {
	echo NOT IMPLEMENTED YET
}

uci_ethernet_client_dhcp() {
	echo NOT IMPLEMENTED YET
}


if [ "$1" == "WIFI_AP" ]
then
	# AP - MODE
	uci_configure_AP
elif [ "$1" == "WIFI_STA" ]
then
	uci_configure_STA
elif [ "$1" == "WIFI_OFF" ]
then
	uci_wifi_OFF
elif [ "$1" == "WIFI_ON" ]
then
	uci_wifi_ON
elif [ "$1" == "ETHERNET_CLIENT_DHCP" ]
then
	uci_ethernet_client_dhcp
elif [ "$1" == "ETHERNET_HOST" ]
then
	uci_ethernet_host
fi
