#!/bin/sh

# $1 ... MODE (AP, STA)
# $2 ... SSID
# $3 ... PASSWORD
# $4 ... ENCRYPTION

mode=$1
ssid=$2
password=$3
encryption=$4

uci_configure_AP() {
	echo "Configure Wifi AccessPoint... ("$ssid", "$encryption")"
	uci -q batch <<EOF
set wireless.ap.encryption='$encryption'
set wireless.ap.key='$password'
set wireless.ap.ssid='$ssid'
set wireless.ap.disabled='0'
set wireless.ap.hidden='0'
set wireless.ap.network='wlan'
set wireless.sta.disabled='1'
set wireless.sta.encryption='none'
set wireless.sta.key=''
set wireless.sta.ssid=''
set wireless.@wifi-config[0].ssid=''
set wireless.@wifi-config[0].encryption=''
set wireless.@wifi-config[0].key=''
set network.wlan.ipaddr='192.168.100.1'
EOF

	# remove any existing wanwifi network
	local bExists=$(uci -q get network.wanwifi)
	if [ "$bExists" != "" ]; then
		uci delete network.wanwifi
	fi
	
	uci commit
	#wifi
	#sleep 3
	#wifi

	/www/ati/scripts/led.sh --network;
#	ifconfig ra0 up
}

uci_configure_STA() {
	echo "Configure Wifi Station..."
	appw=$(head /dev/urandom | tr -dc "0123456789abcdefghijklmnopqrstuvwxyz_-#!*" | cut -c 1-20)
	hostname=$(uci get system.@system[0].hostname)
#	wifisetup clear
#	wifisetup add -ssid "$ssid" -encr $encryption -password $password

	if [ "$(uci -q get wireless.\@wifi-config[0])" != "wifi-config" ]; then
		uci add wireless wifi-config > /dev/null
	fi

	uci -q batch <<EOF
set wireless.sta.encryption='$encryption'
set wireless.sta.key='$password'
set wireless.sta.ssid='$ssid'
set wireless.sta.network='wanwifi'
set wireless.sta.disabled='0'
set wireless.ap.disabled='0'
set wireless.ap.hidden='1'
set wireless.ap.encryption='psk2'
set wireless.ap.key='$appw'
set wireless.sta.disabled='0'
set wireless.@wifi-config[0].ssid='$ssid'
set wireless.@wifi-config[0].encryption='$encryption'
set wireless.@wifi-config[0].key='$password'
set network.wlan.ipaddr='192.168.111.1'
set network.wanwifi=interface
set network.wanwifi.proto='dhcp'
set network.wanwifi.type='bridge'
set network.wanwifi.ifname='eth0'
set network.wanwifi.hostname='$hostname'
EOF

	uci commit
	#wifi

	/www/ati/scripts/led.sh --network;

#	ifconfig ra0 down
}

uci_wifi_OFF() {
	echo "Turn off Wifi..."
	uci -q batch <<EOF
set wireless.sta.disabled='1'
set wireless.ap.disabled='1'
EOF
	uci commit
	wifi
	sleep 3
	wifi
}

uci_wifi_ON() {
	echo "Turn on Wifi..."
	ssid=$(uci -q get wireless.sta.ssid)
	if [ "$ssid" != '' ]; then
		password=$(uci get wireless.sta.key)
		encryption=$(uci get wireless.sta.encryption)
		uci_configure_STA
	else
		ssid=$(uci get wireless.ap.ssid)
		password=$(uci get wireless.ap.key)
		encryption=$(uci get wireless.ap.encryption)
		uci_configure_AP
	fi
}

uci_ethernet_host() {
	# copied from onion.sh

	uci -q batch <<-EOF > /dev/null
		set network.lan=interface
		set network.lan.ifname='eth0'
		set network.lan.force_link='1'
		set network.lan.macaddr='40:a3:6b:c0:27:84'
		set network.lan.type='bridge'
		set network.lan.proto='static'
		set network.lan.ipaddr='192.168.101.1'
		set network.lan.netmask='255.255.255.0'
		set network.lan.ip6assign='60'
		commit network
		set dhcp.lan=dhcp
		set dhcp.lan.interface='lan'
		set dhcp.lan.start='100'
		set dhcp.lan.limit='150'
		set dhcp.lan.leasetime='12h'
		set dhcp.lan.dhcpv6='server'
		set dhcp.lan.ra='server'
		commit dhcp
EOF

	# remove any existing wan network that uses the eth0 interface
	local bExists=$(uci -q get network.wan)
	if [ "$bExists" != "" ]; then
		uci delete network.wan
		uci commit network
	fi


	# restart the network
	/etc/init.d/network restart

}

uci_ethernet_client_dhcp() {
	# copied from onion.sh

	# change the network config
	uci -q batch <<-EOF > /dev/null
		set network.wan=interface
		set network.wan.ifname='eth0'
		set network.wan.proto='dhcp'
		commit network
EOF

	# remove any existing lan network that uses the eth0 interface
	local bExists=$(uci -q get network.lan)
	if [ "$bExists" != "" ]; then
		uci delete network.lan
		uci commit network
	fi

	# remove any lan network DHCP
	local bExists=$(uci -q get dhcp.lan)
	if [ "$bExists" != "" ]; then
		uci delete dhcp.lan
		uci commit dhcp
	fi


	# restart the network
	/etc/init.d/network restart
}


if [ "$1" == "WIFI_AP" ]
then
	# AP - MODE
	uci_configure_AP
elif [ "$1" == "WIFI_STA" ]
then
	uci_configure_STA
elif [ "$1" == "WIFI_OFF" ]
then
	uci_wifi_OFF
elif [ "$1" == "WIFI_ON" ]
then
	uci_wifi_ON
elif [ "$1" == "ETHERNET_CLIENT_DHCP" ]
then
	uci_ethernet_client_dhcp
elif [ "$1" == "ETHERNET_HOST" ]
then
	uci_ethernet_host
fi
